@@ -220,7 +220,6 @@ const CounterUp = {
             }, 50);
           }
         }
-
         counterJs();
         io.unobserve(element);
       }
@@ -291,8 +290,38 @@ const BgSlide = {
   },
 };
 
+const ReadMore = {
+  init: () => {
+    const elements = document.querySelectorAll('span[class="read-more"]');
+    Array.prototype.forEach.call(elements, (el) => {
+      const linkMore = document.createElement('a');
+      linkMore.innerHTML = ' Lire la suite';
+      linkMore.setAttribute('rel', 'nofollow');
+      const parentDiv = el.parentNode;
+      parentDiv.insertBefore(linkMore, el);
+      linkMore.addEventListener('click', (e) => {
+        el.style.display = 'inline';
+        linkMore.remove();
+      });
+    });
+  },
+};
+
+const initAll = function initAllComponents() {
+  SmoothScroll.init();
+  Carousel.init();
+  Clicker.init();
+  Aside.mobile();
+  Lazy.init();
+  Collect.init();
+  Accordion.init();
+  CounterUp.init();
+  Animation.init();
+  BgSlide.init();
+  ReadMore.init();
+};
+
 export default {
-  Image,
   Carousel,
   SmoothScroll,
   Clicker,
@@ -303,4 +332,6 @@ export default {
   CounterUp,
   Animation,
   BgSlide,
+  ReadMore,
+  initAll,
 };
